(_api_reference)=
# API Reference

[Observation](api/observation)
: Details related to defining the observation

[Forward Model](api/forward_model)
: Details related to defining the forward model

[State Vector](api/state_vector)
: Details related to defining the state_vector

[Measurement Vector](api/measurement_vector)
: Details related to the measurement vectors

[Minimizers](api/minimizer.md)
: How the cost function is minimized

[Prior](api/prior)
: How to define Priors

[Processing](api/processing)
: How the main processing script works

```{toctree}
:maxdepth: 2
:hidden:

api/observation
api/forward_model
api/state_vector
api/measurement_vector
api/minimizer
api/prior
api/processing

```
